%define anolis_release 5
%bcond_with tests

Name: procps-ng
Version: 3.3.17
Release: %{anolis_release}%{?dist}
Summary: System and process monitoring utilities
License: GPL+ and GPLv2 and GPLv2+ and GPLv3+ and LGPLv2+
URL: https://sourceforge.net/projects/procps-ng/
Source0: https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.xz

Patch1: pwait-to-pidwait.patch
Patch2: covscan-findings.patch
Patch3: sysctl-hyphen-param.patch
Patch4: free-si-fix.patch
Patch5: sysctl-print-dotted-keys-again.patch
Patch6: cve-2023-4016.patch

BuildRequires: make gcc automake autoconf
BuildRequires: po4a git libtool
BuildRequires: ncurses-devel gettext-devel systemd-devel

%if %{with tests}
BuildRequires: dejagnu
%endif

Provides: procps = %{EVR}
Provides: /sbin/sysctl /bin/ps
Obsoletes: procps < 3.2.9-1

%description
procps is a set of command line and full-screen utilities that provide
information out of the pseudo-filesystem most commonly located at /proc.
This filesystem provides a simple interface to the kernel data structures.
The programs of procps generally concentrate on the structures that describe
the processess running on the system.

The following programs are found in procps:

- free - Report the amount of free and used memory in the system
- kill - Send a signal to a process based on PID
- pgrep - List processes based on name or other attributes
- pkill - Send a signal to a process based on name or other attributes
- pmap - Report memory map of a process
- ps - Report information of processes
- pwdx - Report current directory of a process
- skill - Obsolete version of pgrep/pkill
- slabtop - Display kernel slab cache information in real time
- snice - Renice a process
- sysctl - Read or Write kernel parameters at run-time
- tload - Graphical representation of system load average
- top - Dynamic real-time view of running processes
- uptime - Display how long the system has been running
- vmstat - Report virtual memory statistics
- w - Report logged in users and what they are doing
- watch - Execute a program periodically, showing output fullscreen

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary:  System and process monitoring utilities
Requires: %{name} = %{EVR}
Provides: procps-devel = %{EVR}
Obsoletes: procps-devel < 3.2.9

%description devel
System and process monitoring utilities development headers for %{name}.

%package i18n
Summary:  Internationalization pack for procps-ng
Requires: %{name} = %{EVR}
BuildArch: noarch

Conflicts: man-pages-de < 1.7
Conflicts: man-pages-fr < 3.66
Conflicts: man-pages-pl < 0.7

%description i18n
Internationalization pack for procps-ng

%prep
%autosetup -n procps-%{version} -p1

%build
autoreconf -fiv

%configure \
           --exec-prefix=/ \
           --docdir=/unwanted \
           --disable-static \
           --disable-w-from \
           --disable-kill \
           --enable-watch8bit \
           --enable-skill \
           --enable-sigwinch \
           --enable-libselinux \
           --with-systemd \
           --disable-modern-top\
           --enable-pidwait

make CFLAGS="%{optflags}"

%if %{with tests}
%check
make check
%endif

%install
%make_install

rm -rf %{buildroot}%{_mandir}/{pl,pt_BR,sv}/man5
%find_lang %{name} --all-name --with-man
ln -s %{_bindir}/pidof %{buildroot}%{_sbindir}/pidof

rm -rf %{buildroot}/unwanted/*
%generate_compatibility_deps

%files
%{_bindir}/free
%{_bindir}/pgrep
%{_bindir}/pidof
%{_bindir}/pidwait
%{_bindir}/pkill
%{_bindir}/pmap
%{_bindir}/ps
%{_bindir}/pwdx
%{_bindir}/skill
%{_bindir}/slabtop
%{_bindir}/snice
%{_bindir}/tload
%{_bindir}/top
%{_bindir}/uptime
%{_bindir}/vmstat
%{_bindir}/w
%{_bindir}/watch
%{_sbindir}/pidof
%{_sbindir}/sysctl
%{_libdir}/libprocps.so.8
%{_libdir}/libprocps.so.8.0.3

%dir %{abidir}
%{abidir}/*-option.list
%{abidir}/*.dump

%{_mandir}/man1/*
%{_mandir}/man8/*
%{_mandir}/man5/*
%license COPYING*

%files doc
%doc AUTHORS NEWS
%doc Documentation/bugs.md Documentation/FAQ Documentation/TODO

%files devel
%{_libdir}/libprocps.so
%{_libdir}/pkgconfig/libprocps.pc
%{_includedir}/proc

%license COPYING COPYING.LIB
%{_mandir}/man3/*

%files i18n -f %{name}.lang

%changelog
* Fri Aug 18 2023 Funda Wang <fundawang@yeah.net> - 3.3.17-5
- fix CVE-2023-4016

* Wed Apr 12 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 3.3.17-4
- Refactor the specfile

* Wed Jan 04 2023 happy_orange <songnannan@linux.alibaba.com> - 3.3.17-3
- add some patches and abi api files

* Wed Sep 28 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.3.17-2
- add doc package

* Wed Mar  9 2022 Liwei Ge <liwei.glw@linux.alibaba.com> - 3.3.17-1
- Init version from upstream v3.3.17
